@@ -34,7 +34,7 @@ commentPrefs = ["#"," "]
 
 -- makes Metamath commands that show statements and proofs of theorems
 makeMMscript :: String -> String -> String
-makeMMscript logFile ts = "set scroll continuous\nopen log " ++ logFile ++ "\n" ++ 
+makeMMscript logFile ts = "set scroll continuous\nset width 999\nopen log " ++ logFile ++ "\n" ++ 
    (unlines $ map makeCommand tsc) ++ "close log\nquit\n"
       where 
          tsc = filter (not . null) (rmLinesWithPrefs ts commentPrefs)
@@ -46,10 +46,10 @@ makeMMscript logFile ts = "set scroll continuous\nopen log " ++ logFile ++ "\n"
 
 
 -- MMI input is two strings - the string with known theorems and a string resulting
---- show statement, show proof commands
+--- from show statement, show proof commands
 data MMIinput =
    MMIinput { knownThms :: String, -- "\n" separated list of known theorems 
-              mmout     :: String  -- output from how statement, show proof commands
+              mmout     :: String  -- output from show statement, show proof commands
             } deriving Show
 
 data MMIoutput =
@@ -126,7 +126,7 @@ findNewDeps known thms = ((unionAll (map extrDeps thms)) \\ known) \\ (map thNam
 -- the lines into groups representing single theorems
 splitIntoTheorems :: String -> [[String]]
 splitIntoTheorems s = 
-   splitGroups isShowStatementLine (joinStrsStartingWSpace $ rmLinesWithPrefs s excludedprefs)
+   splitGroups isShowStatementLine (rmLinesWithPrefs s excludedprefs)
 
 -- this is a representation of an MM theorem as a bunch of strings
 data MMTheorem =
@@ -184,9 +184,10 @@ data ProofStep =
 excludedprefs = ["The","MM> close log","$d "]
 
 -- joins any string starting with a space with the previous one
-joinStrsStartingWSpace :: [String] -> [String]
+{-joinStrsStartingWSpace :: [String] -> [String]
 joinStrsStartingWSpace strs = 
    map rmLeadSpacesConcatenate (groupBy secndStrStartsW2Spaces strs)
+-}
 
 -- extracts dependencies from a theorem, a list of all nonempty references in the proof steps,
 -- including the last one
@@ -279,12 +280,12 @@ extrPremiseFormula s = unwords $ stripParens z
    where z = takeWhile (/= "$.") $ tail $ dropWhile (/= "|-") (words s)
 
 -- returns true if the second string out of two starts with a space
-secndStrStartsW2Spaces :: String -> String -> Bool
-secndStrStartsW2Spaces s1 s2 = "  " `isPrefixOf` s2
+--secndStrStartsW2Spaces :: String -> String -> Bool
+--secndStrStartsW2Spaces s1 s2 = "  " `isPrefixOf` s2
 
 -- concatenates a list of strings, removing leading spaces, (except one) from them
-rmLeadSpacesConcatenate :: [String] -> String
-rmLeadSpacesConcatenate strs = foldr1 (++) (map dropSpacesButOne strs)
+--rmLeadSpacesConcatenate :: [String] -> String
+--rmLeadSpacesConcatenate strs = foldr1 (++) (map dropSpacesButOne strs)
 
 -- remove parentheses around a formula if any
 stripParens :: [String] -> [String]
